@@ -36,7 +36,7 @@ def sqlite_s3_query(url, get_credentials=lambda: (
     SQLITE_ROW = 100
     SQLITE_DONE = 101
     SQLITE_TRANSIENT = -1
-    SQLITE_OPEN_READWRITE = 0x00000002
+    SQLITE_OPEN_READONLY = 0x00000001
     SQLITE_OPEN_URI = 0x00000040
 
     bind = {
@@ -185,10 +185,6 @@ def sqlite_s3_query(url, get_credentials=lambda: (
         def x_file_control(p_file, op, p_arg):
             return SQLITE_NOTFOUND
 
-        x_sector_size_type = CFUNCTYPE(c_int, c_void_p)
-        def x_sector_size(p_file):
-            return 0
-
         x_device_characteristics_type = CFUNCTYPE(c_int, c_void_p)
         def x_device_characteristics(p_file):
             return 0
@@ -215,7 +211,7 @@ def sqlite_s3_query(url, get_credentials=lambda: (
             ('x_unlock', c_void_p, None),
             ('x_check_reserved_lock', c_void_p, None),
             ('x_file_control', x_file_control_type, x_file_control_type(x_file_control)),
-            ('x_sector_size', x_sector_size_type, x_sector_size_type(x_sector_size)),
+            ('x_sector_size', c_void_p, None),
             ('x_device_characteristics', x_device_characteristics_type, x_device_characteristics_type(x_device_characteristics)),
         )))
         file = make_struct(tuple((
@@ -251,7 +247,7 @@ def sqlite_s3_query(url, get_credentials=lambda: (
     @contextmanager
     def get_db(vfs):
         db = c_void_p()
-        run(libsqlite3.sqlite3_open_v2, f'file:/{file_name}?immutable=1'.encode() + b'\0', byref(db), SQLITE_OPEN_READWRITE | SQLITE_OPEN_URI, vfs_name.encode())
+        run(libsqlite3.sqlite3_open_v2, f'file:/{file_name}?immutable=1'.encode() + b'\0', byref(db), SQLITE_OPEN_READONLY | SQLITE_OPEN_URI, vfs_name.encode())
         try:
             yield db
         finally:
